@@ -321,7 +321,8 @@ static void cpi_notify(GAtResult *result, gpointer user_data)
 
 	/* Need to send this on the calypso hardware to avoid echo issues */
 	if (msgtype == 3 || msgtype == 4)
-		g_at_chat_send(vd->chat, "AT%N0187", NULL, NULL, NULL, NULL);
+		g_at_chat_send(vd->chat, "AT%N0187", none_prefix,
+				NULL, NULL, NULL);
 
 	switch (msgtype) {
 	case 0:
@@ -390,11 +391,7 @@ static int calypso_voicecall_probe(struct ofono_voicecall *vc, unsigned int vend
 
 	ofono_voicecall_set_data(vc, vd);
 
-	g_at_chat_send(chat, "AT+CLIP=1", NULL, NULL, NULL, NULL);
-	g_at_chat_send(chat, "AT+COLP=0", NULL, NULL, NULL, NULL);
-	g_at_chat_send(chat, "AT+CSSN=1,1", NULL, NULL, NULL, NULL);
-	g_at_chat_send(chat, "AT%CPI=3", NULL, NULL, NULL, NULL);
-	g_at_chat_send(chat, "AT+CCWA=1", NULL,
+	g_at_chat_send(chat, "AT%CPI=3", NULL,
 				calypso_voicecall_initialized, vc, NULL);
 
 	return 0;
